﻿using System.Net;
using System.ServiceModel.Security;
using System.Web;

namespace LearningToolTemplate
{
    /// <summary>
    /// This is the third entry point for your application from itslearning.
    /// It will be called after your application instance is permanently deleted from itslearning.
    /// If your application supports sharing it is also called after instance is deleted from library (in several days).
    /// </summary>
    public class DeleteInstance : IHttpHandler
    {
        public void ProcessRequest(HttpContext context)
        {
            HttpRequest httpRequest = context.Request;
            var parameters = httpRequest.QueryString;

            HttpResponse httpResponse = context.Response;
            httpResponse.ContentType = "text/plain";

            // Validate if the request is not expired and if the signature is valid
            try
            {
                SampleCommunicationHelper.ValidateQueryString(httpRequest.Url.AbsoluteUri, "WRITE YOUR SHARED SECRET HERE", 10, parameters);
            }
            catch (SecurityAccessDeniedException e)
            {
                httpResponse.Write(e.Message);
                httpResponse.StatusCode = (int)HttpStatusCode.Unauthorized;
                return;
            }

            // Learning object Id
            int learningObjectId = int.Parse(httpRequest.QueryString["LearningObjectId"]);

            // Learning object instance Id
            int learningObjectInstanceId = int.Parse(httpRequest.QueryString["LearningObjectInstanceId"]);

            // Use this parameter to identify if it is safe to delete shared content, it is True when last instance of the learning
            // object is deleted and now it is safe to delete learning object. For instance if you have test shared between several courses when one instance
            // is deleted this parameter will be False and you can only delete test results for deleted instance but not test content (description, questions).
            bool safeToDeleteLearningObject = bool.Parse(httpRequest.QueryString["SafeToDeleteLearningObject"]);

            bool errorOccured = false;
            
            // Then your clean up code goes...

            // NOTE: If your operation takes long time (delete files, communicate with external systems, ...) save delete request 
            // and do delete asynchronously

            if (!errorOccured)
            {
                httpResponse.StatusCode = (int)HttpStatusCode.OK;
            }
            else
            {
                // If something went wrong and you are not able to delete data or save request - 
                // just return error status and write problem description into response. 
                // Request will be sent again in this case.
                httpResponse.StatusCode = (int) HttpStatusCode.InternalServerError;
                httpResponse.Write("Error occured: ...");
            }
        }

        public bool IsReusable
        {
            get
            {
                return false;
            }
        }
    }
}