﻿using System;
using System.IO;
using System.Net;
using Itslearning.Platform.RestApi.Sdk.Common.Entities;
using Itslearning.Platform.RestApi.Sdk.LearningToolApp;

namespace LearningToolTemplate
{
    /// <summary>
    /// NOTE: Only provided as a reference. 
    /// NOTE: Not for production usage.
    /// </summary>
    public static class SampleRestApiClient
    {
        /// <summary>
        /// This is a sample call to REST API using .NET proxy class.
        /// </summary>
        /// <param name="apiSession"></param>
        /// <param name="learningObjectId"></param>
        /// <param name="learningObjectInstanceId"></param>
        public static void CallRestApiUsingProxyClass(ApiSession apiSession, int learningObjectId, int learningObjectInstanceId)
        {
            using (var proxy = new LearningObjectServiceClient(apiSession))
            {
                var instance = proxy.GetLearningObjectInstance(learningObjectId, learningObjectInstanceId);
            }
        }


        /// <summary>
        /// This is a sample call to REST API using HTTP request with necessary headers.
        /// </summary>
        /// <param name="applicationKey"></param>
        /// <param name="sharedSecret"></param>
        /// <param name="sessionId"></param>
        /// <param name="learningObjectId"></param>
        /// <param name="learningObjectInstanceId"></param>
        public static void CallRestApiUsingHttpRequest(string applicationKey, string sharedSecret, string sessionId, int learningObjectId, int learningObjectInstanceId)
        {
            // URL to get an instance of learning object
            string url = string.Format("http://betarest.itslearning.com/RestApi/LearningObjectService.svc/LearningObjects/{0}/Instances/{1}", learningObjectId, learningObjectInstanceId);
            var request = (HttpWebRequest) WebRequest.Create(url);
            request.Method = "GET";

            // Construct session object
            var apiSession = new ApiSession();
            // Set here application key which you got when register you tool in itslearning
            apiSession.ApplicationKey = applicationKey;
            // Set the current UTC date and time in format "yyyy-mm-ddThh:mm:ss"
            // itslearning will check the timestamp
            apiSession.LastRequestDateTimeUtc = DateTime.UtcNow;
            // set the sessionId provided by itslearning
            apiSession.SessionId = sessionId;
            // Calculate MD5 on the session data
            apiSession.Hash = SampleCommunicationHelper.ComputeHash(apiSession.ApplicationKey + sharedSecret + apiSession.SessionId + apiSession.TimeStamp);

            // Construct "Authorization" header
            var header = string.Format("{0}#{1}#{2}#{3}",
                                        apiSession.ApplicationKey,
                                        apiSession.SessionId,
                                        apiSession.TimeStamp,
                                        apiSession.Hash);
            request.Headers.Add(HttpRequestHeader.Authorization, header);

            // Call REST API
            using (var response = (HttpWebResponse)request.GetResponse())
            {
                using (var reader = new StreamReader(response.GetResponseStream()))
                {
                    // Here you have response
                    string responseContent = reader.ReadToEnd();
                }
            }
        }
    }
}
